@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2007 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -17,6 +17,18 @@
 |
 |  You should have received a copy of the GNU General Public License
 |  along with this program. If not, see http://www.gnu.org/licenses/
+|
+|
+|  Additional permission under GNU GPL version 3 section 7
+|
+|  If you modify this program, or any covered work, by linking or
+|  combining it with the OpenSSL project's OpenSSL library (or a
+|  modified version of that library), containing parts covered by
+|  the terms of the OpenSSL or SSLeay licenses, you are granted
+|  additional permission to convey the resulting work.
+|  Corresponding Source for a non-source form of such a combination
+|  shall include the source code for the parts of OpenSSL used as well
+|  as that of the covered work.
 */
 
 
@@ -81,6 +93,7 @@ GkrellmChartdata *gkrellm_add_chartdata(GkrellmChart *, GdkPixmap **,
 GkrellmChartdata *gkrellm_add_default_chartdata(GkrellmChart *, gchar *);
 void		gkrellm_alloc_chartdata(GkrellmChart *);
 void		gkrellm_store_chartdata(GkrellmChart *, gulong, ...);
+void		gkrellm_store_chartdatav(GkrellmChart *cp, gulong total, va_list args);
 void		gkrellm_draw_chartdata(GkrellmChart *);
 void		gkrellm_monotonic_chartdata(GkrellmChartdata *, gboolean);
 gboolean	gkrellm_get_chartdata_hide(GkrellmChartdata *);
